@@ -12,7 +12,7 @@ def get_args():
     parser.add_argument("--replace_ids", action="store_true",
                         help="If this is set, the IDs of the bib entries are replaced by a fixed scheme")
     parser.add_argument("--arxiv", action="store_true",
-                        help="If this is set, the primaryClasses are downloaded for arXiv preprints. Requires a eprint field in the entry")
+                        help="If this is set, the primaryClasses are downloaded for arXiv preprints. Requires an eprint field in the entry")
     parser.add_argument("-o", "--output", help="Output file for the clean bib entries. If not specified, it will be the input file with a 'clean-' prefix.")
     parser.add_argument("-v", "--verbose", action="count", default=0, help="Verbosity level. -v is info and -vv is debug")
     return parser
